
 ***********************************************************************************  
 *     T H I S  P R O G R A M    C O M P U T E S   F I N A L    R E S U L T S      *
 ***********************************************************************************

 ///////////////////////////////////////////////////////////////////////////////////
 ///                                                                             ///
 ///  This main program and all its subordinated files include all the code that ///
 ///  is needed to replicate the results in "The Effect of Immigration on Wages: ///
 ///  Exploiting Exogenous Variation at the National Level" by Joan Llull.       ///
 ///                                                                             ///
 ///  HOW TO USE: The following are the main instructions to use this program.   ///
 ///                                                                             ///
 ///  1) Set the relevant paths in your computer. You need to provide:           ///
 ///        data        -> folder where data sets are stored                     ///
 ///        prepared    -> subfolder where prepared data are stored              ///
 ///        datinstr    -> subfolder where instrument data are stored            ///
 ///        datdescript -> subfolder where files for descriptives are stored     ///
 ///                                                                             ///
 ///        estimation  -> folder where code and results are stored              ///
 ///        grfold      -> subfolder where figures are stored                    ///
 ///        tabfold     -> subfolder where tables are stored                     ///
 ///        logfold     -> subfolder where log-files are stored                  ///
 ///        predinstr   -> subfolder where intermediate files are stored         ///
 ///        dofiles     -> subfolder that includes all do files                  ///
 ///                                                                             ///
 ///        instruments -> subsubfolder with do files for instruments            ///
 ///        descriptives-> subsubfolder with do files for descriptives           ///
 ///        preparefiles-> subsubfolder with do files for preparefiles           ///
 ///        first       -> subsubfolder with do files for first stage            ///
 ///        second      -> subsubfolder with do files for second stage           ///
 ///        lasso       -> subsubfolder with do files for lasso results          ///
 ///                                                                             ///
 ///  2) After reading the global variables with the paths, and the programs in  ///
 ///     each of the subordinate files, you need to run each of the programs     ///
 ///	 for the pieces you would like to replicate. These calls are included    ///
 ///     at the end of this main file. You can comment or uncomment as needed.   ///
 ///                                                                             ///
 /// 3) The programs are:                                                        ///
 ///	  instruments  -> Prepares the instruments dataset                       ///
 ///	  descriptives -> Descriptive statistics                                 ///
 ///	  preparefiles -> It prepares the files for first and second stage regs  ///
 ///      results      -> It produces the main results of the paper              ///
 ///                                                                             ///
 /// 4) There are also auxiliary programs called by the two above:               ///
 ///    a) Called by "instruments"                                               ///
 ///      basefile     -> prepare the base file where to merge all others        ///
 ///      distances    -> prepare distance dmeasures                             ///
 ///      pushvars     -> prepare push factors                                   ///
 ///      skillcomp    -> skill composition in source countries                  ///
 ///      bilateral    -> cleans bilat data for exog stocks in networks instr    ///
 ///      cleaninst    -> does the final cleaning to instruments                 ///
 ///      correlations -> computes correlations between push factors (T6)        ///
 ///    b) Called by "descriptives"                                              ///
 ///      maps         -> generate maps from the instruments (F1)                ///
 ///      anecdotal    -> anecdotal evidence (T2, T3, TC1)                       ///
 ///      usbilateral  -> correlation mig and dist after selected push (US)(T4)  ///
 ///      tables_ds    -> saves results in the different tables                  ///
 ///    c) Called by "preparefiles"                                              ///
 ///      gendummies   -> generate dummies for first and second stage regs       ///
 ///      geninteract  -> generate interactions for first stage regs             ///
 ///    d) Called by "results"                                                   ///
 ///      selectlocal  -> defines specific local variables to automatize regs    ///
 ///      regsave      -> computes regression coefficients and standard errors   ///
 ///      tests        -> performs relevance, stability, and signficiance tests  ///
 ///      graphs       -> generates the graphs that check stability of first stg ///
 ///      tables       -> saves results in different tables                      ///
 ///	  tabbaseline  -> The Effect of Immigration on ... (T5 T7 T10 TA1 F2)    ///
 ///	  tabinstr     -> Robustness to Alternative Choices of Instruments (T8)  ///
 ///	  tabfe        -> Robustness to Different Combinations of F.E. (T9)      ///
 ///	  figgaps      -> Summary of Estimated Coefficients and Sub-Sample...(F3)///
 ///      networks     -> Comparison with Networks Instrument for the U.S. (T11) ///
 ///                                                                             ///
 /// 5) The last input for each program should equal 1 if you want nice stata    ///
 ///    output to be displayed (recommended), or anything else (e.g. 0) to       ///
 ///	display all default stata output generated through the process.          ///
 ///                                                                             ///
 ///  This version: October 2016.  Joan Llull, 2016.                            ///
 ///                                                                             ///
 ///////////////////////////////////////////////////////////////////////////////////


	version 12.1
	
	clear
*	clear matrix
	clear mata
	capture log close
	capture program drop _all
	capture label drop _all
	capture set more off
	capture set matsize 11000
	capture set maxvar 32767
	capture set linesize 255
	capture set more on
	pause on
	

  ***** Paths
    
	global unit "/home/joan/Dropbox/"
	*global unit "C:/Users/Joan Llull/Dropbox/"
	global project "Research/5_Immig_Wages/" 

	local path="$unit$project"
	  global data "`path'Raw_data/2016/Final_data/"
	  global estimation "`path'Estimation/2016_10_ij_jk_unbal/"

	local path="$data"
	  global prepared "`path'Prepared/"
	  global datinstr "`path'Raw_Instrument/"
	  global datdescript "`path'Descriptives/"
	  
	local path="$estimation"
	  global grfold "`path'Graphs/"
	  global tabfold "`path'Tables/"
	  global predinstr "`path'Predicted_Instr/"
	  global logfold "`path'LogFiles/" 
	  global dofiles "`path'DoFiles/"
	  
	local path="$dofiles"
	  global instruments "`path'Instruments/"
	  global descriptives "`path'Descriptives/"
	  global preparefiles "`path'Prepare_files/"
	  global results "`path'Results/"

	
 ****************************     M A I N   P R O G R A M    ***********************
	
  **** Read programs
 
	capture program drop _all
	quietly {
		local path="$instruments"
		do "`path'Instruments_main.do"
		do "`path'IN_base_file.do"
		do "`path'IN_distances.do"
		do "`path'IN_push_factors.do"
		do "`path'IN_final_cleaning.do"
		do "`path'IN_correlations_push.do"
		do "`path'IN_bilateral_mig.do"

		local path="$descriptives"
		do "`path'Descriptives_main.do"
		do "`path'DS_anecdotal.do"
		do "`path'DS_US_bilateral.do"
		do "`path'DS_maps.do"
		do "`path'DS_tables.do"

		local path="$preparefiles"
		do "`path'Prepare_files_main.do"
		do "`path'PR_generate_dummies.do"
		do "`path'PR_generate_interactions.do"

		local path="$results"
		do "`path'Results_main.do"
		do "`path'AUX_select_local.do"
		do "`path'AUX_regress_save.do"
		do "`path'AUX_graphs.do"
		do "`path'AUX_tests.do"
		do "`path'AUX_tables.do"
		do "`path'TAB_baseline.do"
		do "`path'TAB_rob_instruments.do"
		do "`path'TAB_rob_fixed_effects.do"
		do "`path'TAB_networks.do"
		do "`path'FIG_gaps.do"
	}

  **** Execute programs

	forvalues i=1/1 {
		cap log close Main_log
		local path="$logfold"
		log using "`path'Main_log.smcl", replace name(Main_log)

		instruments "1"
		descriptives "1"
		preparefiles "1 2" "1"
		/*Options: TBase TRob TFE FGap TNet*/
		results "TBase TRob TFE FGap TNet" "1"

		di " "
		di " "
		log close Main_log
	}


